@@ -4,7 +4,6 @@ use 5.010001;
 
 use Cwd                        qw( );
 use English                    qw( -no_match_vars );
-use Exporter 5.57              qw( import );
 use Fcntl                      qw( :flock :seek );
 use File::Basename               ( );
 use File::Copy                   ( );
@@ -20,27 +19,29 @@ use IO::Dir;
 use IO::File;
 use List::Util                 qw( first );
 use Scalar::Util               qw( blessed );
+use Sub::Install               qw( install_sub );
 use Type::Utils                qw( enum );
 use Unexpected::Functions      qw( InvocantUndefined PathNotFound Unspecified );
 use Unexpected::Types          qw( ArrayRef Bool CodeRef Int Maybe Object
                                    PositiveInt RegexpRef SimpleStr Str );
 use Moo;
 
-use namespace::clean -except => [ 'import', 'meta' ];
+use namespace::clean -except => [ 'meta' ];
 use overload '""'       => sub { $_[ 0 ]->as_string  },
              'bool'     => sub { $_[ 0 ]->as_boolean },
              'fallback' => TRUE;
 
-our @EXPORT    = qw( io );
-
-my  @ARG_NAMES = qw( name mode perms );
 my  $IO_LOCK   = enum 'IO_Lock' => [ FALSE, LOCK_BLOCKING, LOCK_NONBLOCKING ];
 my  $IO_MODE   = enum 'IO_Mode' => [ qw( a a+ r r+ w w+ ) ];
 my  $IO_TYPE   = enum 'IO_Type' => [ qw( dir file ) ];
 my  $LC_OSNAME = lc $OSNAME;
 my  $NTFS      = $LC_OSNAME eq MSOFT || $LC_OSNAME eq CYGWIN ? TRUE : FALSE;
 
-# Private functions
+# Attribute constructors
+my $_build_dir_pattern = sub {
+   my $cd = curdir; my $ud = updir; qr{ \A (?: \Q${cd}\E | \Q${ud}\E ) \z }mx;
+};
+
 my $_expand_tilde = sub {
   (my $path = $_[ 0 ]) =~ m{ \A ([~] [^/\\]*) .* }mx;
 
@@ -56,25 +57,12 @@ my $_coerce_name = sub {
    is_coderef   $name          and $name =  $name->();
    blessed      $name          and $name =  "${name}";
    is_arrayref  $name          and $name =  File::Spec->catfile( @{ $name } );
-   curdir eq    $name          and $name =  Cwd::getcwd();
    first_char   $name eq TILDE and $name =  $_expand_tilde->( $name );
+   curdir eq    $name          and $name =  Cwd::getcwd();
    CORE::length $name > 1      and $name =~ s{ [/\\] \z }{}mx;
    return $name;
 };
 
-my $_should_include_path = sub {
-   return (not defined $_[ 0 ] or (map { $_[ 0 ]->() } ($_[ 1 ]))[ 0 ]);
-};
-
-# Attribute constructors
-my $_build_dir_pattern = sub {
-   my $self = shift; my $curdir = curdir; my $updir = updir;
-
-   my $pat  = "\Q${curdir}\E|\Q${updir}\E";
-
-   return qr{ \A (?:$pat) \z }mx;
-};
-
 # Public attributes
 has 'autoclose'     => is => 'lazy', isa => Bool,           default => TRUE  ;
 has 'have_lock'     => is => 'rwp',  isa => Bool,           default => FALSE ;
@@ -106,10 +94,12 @@ has '_layers'       => is => 'ro',   isa => ArrayRef[SimpleStr],
 has '_lock'         => is => 'rw',   isa => $IO_LOCK,       default => FALSE ;
 has '_no_follow'    => is => 'rw',   isa => Bool,           default => FALSE ;
 has '_separator'    => is => 'rw',   isa => Str,            default => $RS   ;
-has '_umask'        => is => 'rw',   isa => ArrayRef[Int],
+has '_umask'        => is => 'ro',   isa => ArrayRef[Int],
    builder          => sub { [] }                                            ;
 
 # Construction
+my @ARG_NAMES = qw( name mode perms );
+
 my $_clone_one_of_us = sub {
    my ($self, $params) = @_;
 
@@ -154,33 +144,30 @@ sub BUILD {
    return;
 }
 
-my $_proxy = sub { # Methods handled by the IO::Handle object
-   my ($proxy, $chain, $mode) = @_; no strict 'refs';
+sub DEMOLISH {
+   my ($self, $gd) = @_;
 
-   my $package = caller; defined &{ "${package}::${proxy}" } and return;
+   $gd and return; # uncoverable branch true
+   $self->_atomic ? $self->delete : $self->close;
+   return;
+}
 
-   return  *{ "${package}::${proxy}" } = sub {
-      my $self = shift; defined $mode and $self->assert_open( $mode );
+sub import {
+   my ($class, @wanted) = @_; my $package = caller;
 
-      defined $self->io_handle or throw InvocantUndefined, [ $proxy ];
+   (not defined $wanted[ 0 ] or $wanted[ 0 ] eq 'io')
+      and install_sub { into => $package, as => 'io', code => sub (;@) {
+         return $class->new( @_ );
+      } };
 
-      my @results = $self->io_handle->$proxy( @_ ); # Mustn't copy stack args
+   return;
+}
 
-      $self->error_check; $chain and return $self;
-
-      return wantarray ? @results : $results[ 0 ];
-   };
+# Private functions
+my $_should_include_path = sub {
+   return (not defined $_[ 0 ] or (map { $_[ 0 ]->() } ($_[ 1 ]))[ 0 ]);
 };
 
-$_proxy->( 'autoflush', TRUE );
-$_proxy->( 'eof'             );
-$_proxy->( 'fileno'          );
-$_proxy->( 'flush',     TRUE );
-$_proxy->( 'getc',      FALSE, 'r' );
-$_proxy->( 'sysread',   FALSE, O_RDONLY );
-$_proxy->( 'syswrite',  FALSE, O_CREAT | O_WRONLY );
-$_proxy->( 'truncate',  TRUE );
-
 # Private methods
 my $_all_file_contents = sub {
    my $self = shift; $self->is_open or $self->assert_open;
@@ -294,11 +281,10 @@ my $_umask_push = sub {
 };
 
 my $_untainted_perms = sub {
-   my $self = shift; $self->exists or return; my $perms = 0;
-
-   my $stat = $self->stat // {}; my $mode = $stat->{mode} // NUL;
-
-   $mode =~ m{ \A (\d+) \z }mx and $perms = $1;
+   my $self  = shift; $self->exists or return;
+   my $stat  = $self->stat   // {};
+   my $mode  = $stat->{mode} // NUL;
+   my $perms = $mode =~ m{ \A (\d+) \z }mx ? $1 : 0;
 
    return $perms & oct '07777';
 };
@@ -438,11 +424,6 @@ my $_getlines_backwards = sub {
    return @lines;
 };
 
-# Exported functions
-sub io (;@) {
-   return __PACKAGE__->new( @_ );
-}
-
 # Public methods
 sub abs2rel {
    return File::Spec->abs2rel( $_[ 0 ]->name, $_[ 1 ] );
@@ -660,6 +641,7 @@ sub clear {
 sub close {
    my $self = shift; $self->is_open or return $self;
 
+   # uncoverable branch true
    if ($NTFS) { $self->$_close_and_rename } else { $self->$_rename_and_close }
 
    $self->_set_io_handle( undef );
@@ -711,10 +693,6 @@ sub delete_tmp_files {
    return $self->close;
 }
 
-sub DEMOLISH {
-   $_[ 0 ]->_atomic ? $_[ 0 ]->delete : $_[ 0 ]->close; return;
-}
-
 sub digest { # Robbed from Path::Tiny
    my ($self, @args) = @_; my $n = 0; $n++ while (defined $args[ $n ]);
 
@@ -1171,9 +1149,12 @@ sub stat {
 sub substitute {
    my ($self, $search, $replace) = @_;
 
-   $search or return $self; $replace ||= NUL;
+   (defined $search and CORE::length $search) or return $self; $replace //= NUL;
 
-   my $wtr = io( $self->name )->perms( $self->$_untainted_perms )->atomic;
+   my $perms = $self->$_untainted_perms;
+   my $wtr   = $self->$_constructor( $self->name )->atomic;
+
+   $perms and $wtr->perms( $perms );
 
    for ($self->getlines) { s{ $search }{$replace}gmx; $wtr->print( $_ ) }
 
@@ -1266,6 +1247,34 @@ sub write {
    return $length;
 }
 
+# Method installer
+my $_proxy = sub { # Methods handled by the IO::Handle object
+   my ($proxy, $chain, $mode) = @_;
+
+   my $package = caller; $package->can( $proxy ) and return;
+
+   install_sub { into => $package, as => $proxy, code => sub {
+      my $self = shift; defined $mode and $self->assert_open( $mode );
+
+      defined $self->io_handle or throw InvocantUndefined, [ $proxy ];
+
+      my @results = $self->io_handle->$proxy( @_ ); # Mustn't copy stack args
+
+      $self->error_check; $chain and return $self;
+
+      return wantarray ? @results : $results[ 0 ];
+   } };
+};
+
+$_proxy->( 'autoflush', TRUE );
+$_proxy->( 'eof'             );
+$_proxy->( 'fileno'          );
+$_proxy->( 'flush',     TRUE );
+$_proxy->( 'getc',      FALSE, 'r' );
+$_proxy->( 'sysread',   FALSE, O_RDONLY );
+$_proxy->( 'syswrite',  FALSE, O_CREAT | O_WRONLY );
+$_proxy->( 'truncate',  TRUE );
+
 1;
 
 __END__
@@ -1306,6 +1315,9 @@ heavy OO overloading. Only has methods for files and directories
 
 =head1 Configuration and Environment
 
+By default exports the C<io> function which calls the constructor and returns
+the new L<File::DataClass::IO> object
+
 L<File::DataClass::Constants> has a class attribute C<Exception_Class> which
 defaults to L<File::DataClass::Exception>. Set this attribute to the
 classname used by the L</_throw> method
@@ -1804,12 +1816,6 @@ Returns a hexadecimal string which is calculated from the L</digest> object
 Sets default values for some attributes, takes two optional arguments;
 C<type> and C<name>
 
-=head2 io
-
-   $io = io( 'path_to_file' );
-
-Subroutine exported by default. Returns a new IO object
-
 =head2 is_absolute
 
    $bool = io( 'path_to_file' )->is_absolute;
@@ -2209,8 +2215,6 @@ None
 
 =item L<overload>
 
-=item L<Exporter>
-
 =item L<File::DataClass::Constants>
 
 =item L<Moo>
